@@ -1,83 +1,79 @@
 =head1 NAME
 
-Bot::BasicBot::Pluggable::Module::Join
-
-=head1 SYNOPSIS
-
-Keeps track of what channels the bot wants to be in, will leave and join
-channels on request. Load this module, and you can tell the bot 'join #channel',
-'leave #channel', and it will remember it's state.
+Bot::BasicBot::Pluggable::Module::Join - join and leave channels; remembers state
 
 =head1 IRC USAGE
 
-Commands:
-
 =over 4
 
 =item join <channel>
 
-Joins a channel
-
 =item part <channel>
 
-Leaves a channel
-
 =item channels
 
-List the channels the bot is in
+List the channels the bot is in.
 
 =back
 
+=head1 METHODS
+
+=over 4
+
+=item add_channel($channel)
+
+=item remove_channel($channel)
+
+=back
+
+=head1 AUTHOR
+
+Tom Insam <tom@jerakeen.org>
+
+This program is free software; you can redistribute it
+and/or modify it under the same terms as Perl itself.
+
 =cut
 
 package Bot::BasicBot::Pluggable::Module::Join;
+use base qw(Bot::BasicBot::Pluggable::Module);
 use warnings;
 use strict;
 
-use Bot::BasicBot::Pluggable::Module;
-use base qw(Bot::BasicBot::Pluggable::Module);
-
 sub connected {
     my $self = shift;
 
     my @channels = split(/\s+/, $self->get("channels") || "");
     for (@channels) {
-        print "Joining $_\n";
+        print "Joining $_.\n";
         $self->{Bot}->join($_);
     }
 }
 
 sub help {
-    my ($self, $mess) = @_;
-    return "Handles joining and leaving channels. ".
-    "usage: join <channel>, leave <channel>, channels. ".
-    "Requires direct addressing.";
+    return "Join and leave channels. Usage: join <channel>, leave <channel>, channels. Requires direct addressing.";
 }
 
-sub said {
-    my ($self, $mess, $pri) = @_;
-
+sub told {
+    my ($self, $mess) = @_;
     my $body = $mess->{body};
-
-    return unless $mess->{address} and $pri == 2;
+	return unless defined $body;
+    return unless $mess->{address};
 
     my ($command, $param) = split(/\s+/, $body, 2);
     $command = lc($command);
-    $command =~ s/\?$//;
 
     if ($command eq "join") {
         $self->add_channel($param);
         return "Ok.";
 
     } elsif ($command eq "leave" or $command eq "part") {
-        $self->remove_channel($param || $mess->{channel} );
+        $self->remove_channel($param || $mess->{channel});
         return "Ok.";
 
     } elsif ($command eq "channels") {
-        return "I'm in ".$self->get("channels");
+        return "I'm in ".$self->get("channels").".";
     }
-
-    return undef;
 }
 
 sub add_channel {
